@@ -8,5 +8,5 @@ class MetadataTypesEndpoint(SemanthaAPIEndpoint):
     def _endpoint(self):
         return self._parent_endpoint + "/metadatatypes"
 
-    def get_metadatatypes(self):
+    def get(self):
         pass
