@@ -15,4 +15,4 @@ class DataPropertiesEndpoint(SemanthaAPIEndpoint):
     def post(self, domain: str, body: dict):
         """ (Not yet implemented) """
         raise NotImplementedError("Not  yet implemented!")
-        return self._session.post(f"/api/domains/{domain.lower()}/dataproperties", body).execute()
+        return self._session.post(f"/api/domains/{domain.lower()}/dataproperties", ).execute()
