@@ -8,5 +8,5 @@ class ExtractorTypesEndpoint(SemanthaAPIEndpoint):
     def _endpoint(self):
         return self._parent_endpoint + "/extractortypes"
 
-    def get_extractortypes(self):
+    def get(self):
         pass
\ No newline at end of file
