@@ -6,12 +6,12 @@ class InstancesEndpoint:
         self.__session = session
         self.__api_endpoint = api_endpoint
 
-    def get_instances(self):
+    def get(self):
         """ (Not yet implemented) """
         raise NotImplementedError("Not yet implemented!")
         return self.__session.get(self.__api_endpoint).execute()
 
-    def post_domain_classes(self, body: dict):
+    def post(self, body: dict):
         """ (Not yet implemented) """
         raise NotImplementedError("Not yet implemented!")
-        return self.__session.post(self.__api_endpoint, body).execute()
+        return self.__session.post(self.__api_endpoint, ).execute()
