@@ -2,7 +2,7 @@ from .semantha_entity import SemanthaModelEntity
 from .reference import Reference
 from .paragraph import Paragraph
 from .page import Page
-from .domain import Domains
+from .domain import Domain
 from .cls import Class
 from .data_type import DataType
 from .label import Label
