@@ -8,6 +8,7 @@ from marshmallow_dataclass import class_schema
 from semantha_sdk.model.reference import Reference
 from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
 from semantha_sdk.model.sentence import Sentence
+from semantha_sdk.model.area import Area
 
 
 @dataclass(frozen=True)
@@ -17,6 +18,7 @@ class Paragraph(SemanthaModelEntity):
     text: str
     sentences: Optional[List[Sentence]]
     document_name: Optional[str]
+    areas: Optional[List[Area]]
     references: Optional[List[Reference]]
     context: Optional[Dict[str, str]]
     comment: Optional[str]
