@@ -2,7 +2,7 @@ from abc import ABC
 from dataclasses import dataclass
 from typing import Type
 
-from marshmallow import Schema
+from marshmallow import Schema, EXCLUDE
 import humps
 
 
@@ -19,5 +19,8 @@ def with_entity(cls: Type[SemanthaModelEntity]):
 
 
 class SemanthaSchema(Schema):
+    # ignore unknown properties in json, we need this for older clients to access newer servers:
+    class Meta:
+        unknown = EXCLUDE
     def on_bind_field(self, field_name, field_obj):
         field_obj.data_key = humps.camelize(field_obj.data_key or field_name)
